// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "asset/AssetLoader.hpp"
#include "asset/AssetDataLoader.hpp"

namespace Dawn {
  enum class JSONLoaderLoadState {
    INITIAL,
    LOADING_FILE,
    PARSING_DATA,
    DONE
  };

  class JSONLoader : public AssetLoader {
    protected:
      AssetDataLoader loader;
      enum JSONLoaderLoadState state;

    public:
      std::shared_ptr<json> data;

      /**
       * Constructs a JSON asset loader. You should instead use the parent
       * asset managers' abstracted load method
       * 
       * @param name File name asset to load, omitting the extension.
       */
      JSONLoader(const std::string name);

      void updateSync() override;
      void updateAsync() override;

      /**
       * Dispose / Cleanup the JSON asset.
       */
      ~JSONLoader();
  };
}